@@ -5,11 +5,14 @@
 #include <dirent.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <string.h>
 
-// function getProcessID(char*) used to find process id
+// modified function getProcessID(char*) used to find process id
 // taken from http://www.linuxforums.org/forum/programming-scripting/40078-c-printing-linux-process-table.html
-unsigned int getProcessID(char *p_processname)
+unsigned int checkServerRunning()
 {
+	char *p_processname="python";
+	char *p_commandlinearg="/opt/mmmrpcserver/mmmrpcserver.py";
 	DIR *dir_p;
 	struct dirent *dir_entry_p;
 	char dir_name[40];				// ??? buffer overrun potential
@@ -38,17 +41,39 @@ unsigned int getProcessID(char *p_processname)
 			{
 				target_name[target_result] = 0;
 				if (strstr(target_name, p_processname) != NULL) 
-				{	// Searching for process name in the target name -- ??? could be a better search !!!
-					result = atoi(dir_entry_p->d_name);
-					printf("getProcessID(&#37;s) :Found. id = %d\n", p_processname, result);
-					closedir(dir_p);
-					return result;
+				{
+					char cmd_file[252];
+					char argument[252];
+					int tmpchar, prev=1, which=0, which2=0, readstill=1;
+					cmd_file[0] = 0;
+					FILE *f2=NULL;
+					strcat(cmd_file, dir_name);
+					strcat(cmd_file, "cmdline");
+					f2 = fopen(cmd_file, "rb");
+					if(f2==NULL)
+						readstill = 0;
+					while(readstill>0)
+					{
+						tmpchar = fgetc(f2);
+						if(tmpchar==0 && which>6 || which2>250)
+							readstill = 0;
+						if(which>6)
+							argument[which2++] = tmpchar;
+						which++;
+					}
+					argument[which2]=0;
+					fclose(f2);
+					if(strstr(argument, p_commandlinearg)!=NULL)
+					{
+						result = atoi(dir_entry_p->d_name);\
+						closedir(dir_p);
+						return result;
+					}
 				}
 			}
 		}
 	}
 	closedir(dir_p);
-	printf("getProcessID(%s) : id = 0 (could not find process)\n", p_processname);
 	return result;
 }
 
@@ -60,23 +85,33 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	GtkWidget *box;
 	gint response;
 	unsigned int result;
-	/* Create dialog with OK and Cancel buttons. Leave the separator out,
-	 * as we do not have any content. */
-	dialog = gtk_dialog_new_with_buttons(
-		"mmmRemotePhoneControl config",
-		GTK_WINDOW(data),
-		GTK_DIALOG_MODAL,
-		GTK_STOCK_OK,
-		GTK_RESPONSE_OK,
-		GTK_STOCK_CANCEL,
-		GTK_RESPONSE_CANCEL,
-		NULL);
-	/* ... add something to the dialog ... */
-	result = getProcessID("/opt/mmmrpcserver/final-server.py");
+	result = checkServerRunning();
 	if(result>0)
+	{
+		dialog = gtk_dialog_new_with_buttons(
+			"mmmRemotePhoneControl config",
+			GTK_WINDOW(data),
+			GTK_DIALOG_MODAL,
+			"Stop server",
+			GTK_RESPONSE_OK,
+			GTK_STOCK_CANCEL,
+			GTK_RESPONSE_CANCEL,
+			NULL);
 		label = gtk_label_new("Server is running now");
+	}
 	else
+	{
+		dialog = gtk_dialog_new_with_buttons(
+			"mmmRemotePhoneControl config",
+			GTK_WINDOW(data),
+			GTK_DIALOG_MODAL,
+			"Start server",
+			GTK_RESPONSE_OK,
+			GTK_STOCK_CANCEL,
+			GTK_RESPONSE_CANCEL,
+			NULL);
 		label = gtk_label_new("Server is not running now");
+	}
 	box = gtk_dialog_get_content_area(GTK_DIALOG(dialog));
 	gtk_box_pack_start(GTK_BOX(box), label, TRUE, TRUE, 0);
 	if (!user_activated)
@@ -88,7 +123,17 @@ osso_return_t execute(osso_context_t *osso, gpointer data, gboolean user_activat
 	response = gtk_dialog_run(GTK_DIALOG(dialog));
 	if (response == GTK_RESPONSE_OK)
 	{
-		/* ... do something with the dialog stuff ... */
+		if(result>0)
+		{
+			char command[1000];
+			command[0] = 0;
+			sprintf(command, "kill %u", result);
+			system(command);
+		}
+		else
+		{
+			system("python /opt/mmmrpcserver/mmmrpcserver.py >/home/user/MyDocs/mmmrpcclient/log.txt &");
+		}
 	}
 	/* Free the dialog (and it's children) */
 	gtk_widget_destroy(GTK_WIDGET(dialog));
